@@ -47,6 +47,7 @@
 #include <access.h>
 #include <readcfg.h>
 #include <main.h>
+#include <time.h>
 
 
 BAUD baud[] = {
@@ -798,6 +799,8 @@ ConsDown(CONSENT *pCE, FLAG downHard, FLAG force)
     if (pCE->type == EXEC && pCE->execSlaveFD != 0) {
 	close(pCE->execSlaveFD);
 	pCE->execSlaveFD = 0;
+	free(pCE->execSlave);
+	pCE->execSlave = NULL;
     }
     pCE->fup = 0;
     pCE->nolog = 0;
@@ -913,6 +916,9 @@ ConsInit(CONSENT *pCE)
 	case HOST:
 	    {
 #if USE_IPV6
+		/* XXX IPv4 should use getaddrinfo() and getnameinfo() as well,
+		 * (if available, they are in IEEE Std 1003.1g-2000)
+		 */
 		int error;
 		char host[NI_MAXHOST];
 		char serv[NI_MAXSERV];
@@ -927,7 +933,7 @@ ConsInit(CONSENT *pCE)
 		Sleep(100000);	/* Not all terminal servers can keep up */
 
 #if USE_IPV6
-# if HAVE_MEMSET
+# if HAVE_MEMSET		/* XXX memset() is C89!!! */
 		memset(&hints, 0, sizeof(hints));
 # else
 		bzero(&hints, sizeof(hints));
@@ -964,8 +970,12 @@ ConsInit(CONSENT *pCE)
 # if HAVE_SETSOCKOPT
 			if (setsockopt
 			    (cofile, SOL_SOCKET, SO_KEEPALIVE,
-			     (char *)&one, sizeof(one)) < 0)
+			     (char *)&one, sizeof(one)) < 0) {
+			    Error
+				("[%s] %s:%s setsockopt(%u,SO_KEEPALIVE): %s",
+				 pCE->server, host, serv, cofile, strerror(errno));
 			    goto fail;
+			}
 # endif
 			if (!SetFlags(cofile, O_NONBLOCK, 0))
 			    goto fail;
@@ -973,20 +983,25 @@ ConsInit(CONSENT *pCE)
 			ret = connect(cofile, rp->ai_addr, rp->ai_addrlen);
 			if (ret == 0 || errno == EINPROGRESS)
 			    goto success;
-
+			Error("[%s] %s:%s connect(%u): %s",
+			      pCE->server, host, serv, cofile, strerror(errno));
 		      fail:
 			close(cofile);
+		    } else {
+			Error
+			    ("[%s] %s:%s socket(AF_INET,SOCK_STREAM): %s",
+			     pCE->server, host, serv, strerror(errno));
 		    }
 		    rp = rp->ai_next;
 		}
 
-		Error("[%s]: Unable to connect to %s:%s", pCE->server,
-		      host, serv);
+		Error("[%s] Unable to connect to %s:%s, forcing down", pCE->server,
+		      pCE->host, serv);
 		ConsDown(pCE, FLAGTRUE, FLAGTRUE);
 		return;
 	      success:
 		freeaddrinfo(ai);
-#else
+#else  /* !USE_IPV6 */
 # if HAVE_MEMSET
 		memset((void *)&port, 0, sizeof(port));
 # else
@@ -1308,7 +1323,7 @@ AddrsMatch(char *addr1, char *addr2)
 {
 #if USE_IPV6
     int error, ret = 0;
-    struct addrinfo *ai1, *ai2, hints;
+    struct addrinfo *ai1, *ai2, *rp1, *rp2, hints;
 #else
     /* so, since we might use inet_addr, we're going to use
      * (in_addr_t)(-1) as a sign of an invalid ip address.
@@ -1346,17 +1361,19 @@ AddrsMatch(char *addr1, char *addr2)
 	goto done;
     }
 
-    for (; ai1 != NULL; ai1 = ai1->ai_next) {
-	for (; ai2 != NULL; ai2 = ai2->ai_next) {
-	    if (ai1->ai_addr->sa_family != ai2->ai_addr->sa_family)
+    rp1 = ai1;
+    rp2 = ai2;
+    for (; rp1 != NULL; rp1 = rp1->ai_next) {
+	for (; rp2 != NULL; rp2 = rp2->ai_next) {
+	    if (rp1->ai_addr->sa_family != rp2->ai_addr->sa_family)
 		continue;
 
 	    if (
 # if HAVE_MEMCMP
-		   memcmp(&ai1->ai_addr, &ai2->ai_addr,
+		   memcmp(&rp1->ai_addr, &rp2->ai_addr,
 			  sizeof(struct sockaddr_storage))
 # else
-		   bcmp(&ai1->ai_addr, &ai2->ai_addr,
+		   bcmp(&rp1->ai_addr, &rp2->ai_addr,
 			sizeof(struct sockaddr_storage))
 # endif
 		   == 0) {
