@@ -7,6 +7,7 @@
 #include <compat.h>
 
 #include <cutil.h>
+#include <time.h>
 #include <version.h>
 
 #include <net/if.h>
@@ -262,7 +263,7 @@ DestroyString(STRING *msg)
 {
     if (msg->prev == (STRING *)0 && msg->next == (STRING *)0 &&
 	allStrings != msg) {
-	CONDDEBUG((1, "DestroyString(): 0x%lx non-pooled string destroyed",
+	CONDDEBUG((3, "DestroyString(): 0x%lx non-pooled string destroyed",
 		   (void *)msg, stringCount));
     } else {
 	if (msg->prev != (STRING *)0)
@@ -273,7 +274,7 @@ DestroyString(STRING *msg)
 	    allStrings = msg->next;
 	}
 	stringCount--;
-	CONDDEBUG((1,
+	CONDDEBUG((3,
 		   "DestroyString(): 0x%lx string destroyed (count==%d)",
 		   (void *)msg, stringCount));
     }
@@ -296,7 +297,7 @@ AllocString(void)
     allStrings = s;
     InitString(s);
     stringCount++;
-    CONDDEBUG((1, "AllocString(): 0x%lx created string #%d", (void *)s,
+    CONDDEBUG((3, "AllocString(): 0x%lx created string #%d", (void *)s,
 	       stringCount));
     return s;
 }
@@ -546,7 +547,7 @@ Verbose(char *fmt, ...)
 }
 
 void
-SimpleSignal(int sig, RETSIGTYPE(*disp) (int))
+SimpleSignal(int sig, void(*disp) (int))
 {
 #if HAVE_SIGACTION
     struct sigaction sa;
@@ -708,7 +709,7 @@ FileUnopen(CONSFILE *cfp)
 	    break;
 #if HAVE_OPENSSL
 	case SSLSocket:
-	    retval = -1;
+	    retval = cfp->fd;
 	    break;
 #endif
 	default:
@@ -2415,7 +2416,7 @@ GetWord(FILE *fp, int *line, short spaceok, STRING *word)
     while ((c = fgetc(fp)) != EOF) {
 	if (c == '\n') {
 	    (*line)++;
-	    if (checkInc == -2)
+	    if (checkInc == -2 || checkInc == 0)
 		checkInc = -1;
 	}
 	if (comment) {
@@ -2592,11 +2593,17 @@ ParseFile(char *filename, FILE *fp, int level)
 			  strerror(errno));
 	    } else {
 		char *fname;
+		char *sfile;
+		int sline;
 		/* word gets destroyed, so save the name */
 		fname = StrDup(word->string);
+		sfile = file;
+		sline = line;
 		ParseFile(fname, lfp, level + 1);
 		fclose(lfp);
 		free(fname);
+		file = sfile;
+		line = sline;
 	    }
 	} else {
 	    switch (state) {
